;----------------------------------------------------------------------
;
; Procedure : SerialOut
;
; Sends a string via Txd, stops transmission with char 0x00
;
; Entry : Pointer to string in Z register
; Exit  :
; Destroys :
;
;----------------------------------------------------------------------
SerialOut:					;
	lpm						;Read char from string in flash
	mov		temp,r0			;Load char from r0 into temp
	cpi		temp,0x00		;if char = 000h
	breq	SerialOut_exit	; then jump to exit
							; else
	out		UDR,temp		;  Put the data in the transmit register
	adiw	ZL,1			;  increment pointer
							;
	rcall	WaitTX			;
							;end if
	rjmp	SerialOut		;next char
							;
SerialOut_exit:				;
	ret						;	

;SerialOut	endp

;----------------------------------------------------------------------
;
; Procedure : WaitTX
;
; Wait until transmission done
;
; Entry :
; Exit  :
; Destroys : temp3
;
;----------------------------------------------------------------------
WaitTX:					;
	in		temp3,USR	;Wait until data is sent
	sbrs	temp3,UDRE	;		
	rjmp	WaitTX		;
						;
WaitTX_exit:			;
	ret					;

;WaitTX	endp

;----------------------------------------------------------------------
;
; Procedure : sendchar
;
; send a character via serial UART
;
; Entry :
; Exit  :
; Destroys : 
;
;----------------------------------------------------------------------
sendchar:
	out		UDR,temp		;Put the data in the transmit register
	rcall	WaitTX			;
							;
sendc_exit:					;
	ret						;

;sendchar	endp

;----------------------------------------------------------------------
;
; Procedure : byte2asc
; 
; Convert a byte in 3 decimal ASCII characters       (0..255)
; Umwandlung eines bytes in 3 dezimale ASCII-Zeichen (0..255)
;
; Entry : BAlb = R8 = byte to convert
; Exit  : R12 = Asc1 = 1.Char
;		  R13 = Asc2 = 2.Char
;		  R14 = Asc3 = 3.Char
; Destroys : 
;
;----------------------------------------------------------------------
byte2asc:
	clr		BAhb			;clear data hibyte (not used here)
	clr 	Divhb			;clear divisor hibyte (not used here)
							;
	ldi 	rmp,100			;Setze Dezimalteiler auf 100
	mov 	Divlb,rmp		;
	rcall 	conv	 		;Hole die nchste Ziffer
	mov 	Asc1,rmp 		;Setze Hunderter Zeichen

	ldi 	rmp,10 			;Setze Dezimalteiler auf 10
	mov 	Divlb,rmp		;
	rcall 	conv	 		;Hole die nchste Ziffer
	mov 	Asc2,rmp 		;Setze Zehner Zeichen

	ldi 	rmp,'0' 		;Wandle Rest in ASCII-Ziffer um
	add 	rmp,BAlb		;
	mov 	Asc3,rmp		;Setze Einer Zeichen
	ret
;
; Wandle Binrwort in BAhb:BAlb(R9:R8) in ASCII-Zeichen einer Dezimalziffer durch fortgesetztes
; Abziehen des Dezimalteilers in Divhb:Divlb(R11:R10) (z.b. 10000, 1000, 100, 10)
;
conv:						;
	ldi 	rmp,'0' 		; Beginne mit ASCII-0
conv1:						;
	cp 		BAlb,Divlb		; Vergleiche Wort mit Teiler
	cpc 	BAhb,Divhb		;
	brcc 	conv2	 		; Carry nicht gesetzt, subtrahiere Teiler
	ret 					; fertig
conv2:						;
	sub 	BAlb,Divlb		; Subtrahiere Teilerwert
	sbc 	BAhb,Divhb		;
	inc 	rmp 			; Ziffer um eins erhhen
	rjmp 	conv1	 		; und noch einmal von vorne

;byte2asc	endp
